pub struct SimdOp { /* private fields */ }Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SimdOp
impl<'de> Deserialize<'de> for SimdOp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Input for SimdOp
impl Input for SimdOp
Sourcetype Raw = SimdOp
type Raw = SimdOp
The raw form of this input that is deserialized from input files and serialized as
examples. The raw nature of this type reflects that no input
validation has been performed beyond the checks performed by its
Deserialize implementation. Read moreAuto Trait Implementations
impl Freeze for SimdOp
impl RefUnwindSafe for SimdOp
impl Send for SimdOp
impl Sync for SimdOp
impl Unpin for SimdOp
impl UnsafeUnpin for SimdOp
impl UnwindSafe for SimdOp